#ifndef WALLPAEPER_H
#define WALLPAEPER_H

#include <QMainWindow>
#include <QMenu>
#include <QMenuBar>

class wpNew;
class wpManager;
class aboutDialog;

namespace Ui {
    class wallPaeper;
}

class wallPaeper : public QMainWindow
{
    Q_OBJECT

public:
    explicit wallPaeper(QWidget *parent = 0);
    ~wallPaeper();

private:
    Ui::wallPaeper *ui;

    void setupWPMenuBar();
    QMenuBar* wpMenuBar;

    aboutDialog* abtDialog;
    wpNew* newWin;
    wpManager* manWin;
    bool openManWin;
    bool openNewWin;

public slots:
    void createAbtDialog();
    void createAbtQtDialog();
    void newBtnClicked();
    void manBtnClicked();
    void openWinTrue();
};

#endif // WALLPAEPER_H
